import { DataSource, ViewEntity, ViewColumn } from 'typeorm';
import { Carrito } from '../../../carrito/entity/carrito.entity';
import { Equipo } from '../equipo.entity';
import { Institucion } from '../../../institucion/entity/institucion.entity';
import { Modulo } from '../../../modulo/entity/modulo.entity';
import { EquipoPrograma } from '../../../equipo-programa/entity/equipo-programa.entity';
import { EquipoTipoEntrada } from '../../../equipo-tipo-entrada/entity/equipo-tipo-entrada.entity';
import { Programa } from '../../../institucion-programa/entity/programa.entity';
import { Status } from '../../../status/entity/status.entity';
import { TipoCarrito } from '../../../institucion-tipo-carrito/entity/tipo-carrito.entity';
import { TipoEntrada } from '../../../institucion-tipo-entrada/entity/tipo-entrada.entity';

@ViewEntity({
  expression: (dataSource: DataSource) =>
    dataSource
      .createQueryBuilder()
      .select('e.id_equipo', 'id_equipo')
      .addSelect('e.equipo', 'equipo')
      .addSelect('e.id_carrito', 'id_carrito')
      .addSelect('e.id_status', 'id_status')
      .addSelect('e.numero_inventario', 'numero_inventario')
      .addSelect('e.numero_serie', 'numero_serie')
      .addSelect('e.prestado', 'prestado')
      .addSelect('c.activo', 'activo_carrito')
      .addSelect('c.carrito', 'carrito')
      .addSelect('c.id_modulo', 'id_modulo')
      .addSelect('c.id_tipo_carrito', 'id_tipo_carrito')
      .addSelect('s.status', 'status')
      .addSelect('ps.id_programa', 'id_programa')
      .addSelect('tes.id_tipo_entrada', 'id_tipo_entrada')
      .addSelect('m.activo', 'activo_modulo')
      .addSelect('m.id_institucion', 'id_institucion')
      .addSelect('m.modulo', 'modulo')
      .addSelect('tc.tipo_carrito', 'tipo_carrito')
      .addSelect('p.programa', 'programa')
      .addSelect('te.tipo_entrada', 'tipo_entrada')
      .addSelect('i.activo', 'activo_institucion')
      .addSelect('i.institucion', 'institucion')
      .from(Equipo, 'e')
      .innerJoin(Carrito, 'c', 'c.id_carrito = e.id_carrito')
      .innerJoin(Status, 's', 's.id_status = e.id_status')
      .innerJoin(EquipoPrograma, 'ps', 'ps.id_equipo = e.id_equipo')
      .innerJoin(EquipoTipoEntrada, 'tes', 'tes.id_equipo = e.id_equipo')
      .innerJoin(Modulo, 'm', 'm.id_modulo = c.id_modulo')
      .innerJoin(TipoCarrito, 'tc', 'tc.id_tipo_carrito = c.id_tipo_carrito')
      .innerJoin(Programa, 'p', 'p.id_programa = ps.id_programa')
      .innerJoin(TipoEntrada, 'te', 'te.id_tipo_entrada = tes.id_tipo_entrada')
      .innerJoin(Institucion, 'i', 'i.id_institucion = m.id_institucion'),
})
export class FullInformacionEquipoView {
  @ViewColumn()
  id_equipo: number;

  @ViewColumn()
  activo_carrito: boolean;

  @ViewColumn()
  activo_institucion: boolean;

  @ViewColumn()
  activo_modulo: boolean;

  @ViewColumn()
  carrito: string;

  @ViewColumn()
  equipo: string;

  @ViewColumn()
  id_carrito: number;

  @ViewColumn()
  id_institucion: number;

  @ViewColumn()
  id_modulo: number;

  @ViewColumn()
  id_programa: number;

  @ViewColumn()
  id_tipo_carrito: number;

  @ViewColumn()
  id_tipo_entrada: number;

  @ViewColumn()
  id_status: number;

  @ViewColumn()
  institucion: string;

  @ViewColumn()
  modulo: string;

  @ViewColumn()
  numero_inventario: string;

  @ViewColumn()
  numero_serie: string;

  @ViewColumn()
  prestado: boolean;

  @ViewColumn()
  programa: string;

  @ViewColumn()
  status: string;

  @ViewColumn()
  tipo_carrito: string;

  @ViewColumn()
  tipo_entrada: string;
}
