import { DataSource, ViewEntity, ViewColumn } from 'typeorm';
import { Carrito } from '../../../carrito/entity/carrito.entity';
import { Equipo } from '../equipo.entity';
import { Institucion } from '../../../institucion/entity/institucion.entity';
import { Modulo } from '../../../modulo/entity/modulo.entity';

@ViewEntity({
  expression: (dataSource: DataSource) =>
    dataSource
      .createQueryBuilder()
      .select('e.id_equipo', 'id_equipo')
      .addSelect('e.equipo', 'equipo')
      .addSelect('e.id_carrito', 'id_carrito')
      .addSelect('e.id_status', 'id_status')
      .addSelect('e.numero_inventario', 'numero_inventario')
      .addSelect('e.prestado', 'prestado')
      .addSelect('c.activo', 'activo_carrito')
      .addSelect('c.carrito', 'carrito')
      .addSelect('c.id_modulo', 'id_modulo')
      .addSelect('c.id_tipo_carrito', 'id_tipo_carrito')
      .addSelect('m.activo', 'activo_modulo')
      .addSelect('m.id_institucion', 'id_institucion')
      .addSelect('i.activo', 'activo_institucion')
      .from(Equipo, 'e')
      .innerJoin(Carrito, 'c', 'c.id_carrito = e.id_carrito')
      .innerJoin(Modulo, 'm', 'm.id_modulo = c.id_modulo')
      .innerJoin(Institucion, 'i', 'i.id_institucion = m.id_institucion'),
})
export class InformacionEquipoView {
  @ViewColumn()
  id_equipo: number;

  @ViewColumn()
  activo_carrito: boolean;

  @ViewColumn()
  activo_institucion: boolean;

  @ViewColumn()
  activo_modulo: boolean;

  @ViewColumn()
  carrito: string;

  @ViewColumn()
  equipo: string;

  @ViewColumn()
  id_carrito: number;

  @ViewColumn()
  id_institucion: number;

  @ViewColumn()
  id_modulo: number;

  @ViewColumn()
  id_tipo_carrito: number;

  @ViewColumn()
  id_status: number;

  @ViewColumn()
  numero_inventario: string;

  @ViewColumn()
  prestado: boolean;
}
