import { DataSource, ViewEntity, ViewColumn } from 'typeorm';
import { Carrito } from '../../../carrito/entity/carrito.entity';
import { Prestamo } from '../prestamo.entity';
import { Equipo } from '../../../equipo/entity/equipo.entity';
import { Institucion } from '../../../institucion/entity/institucion.entity';
import { Modulo } from '../../../modulo/entity/modulo.entity';
import { Operador } from '../../../operador/entity/operador.entity';
import { Status } from '../../../status/entity/status.entity';
import { TipoCarrito } from '../../../institucion-tipo-carrito/entity/tipo-carrito.entity';
import { Usuario } from '../../../usuario/entity/usuario.entity';

@ViewEntity({
  expression: (dataSource: DataSource) =>
    dataSource
      .createQueryBuilder()
      .select('p.id_prestamo', 'id_prestamo')
      .addSelect('p.activo', 'activo_prestamo')
      .addSelect('p.cancelado_operador', 'cancelado_operador')
      .addSelect('p.cancelado_usuario', 'cancelado_usuario')
      .addSelect('p.fecha_entrega', 'fecha_entrega')
      .addSelect('p.fecha_inicio', 'fecha_inicio')
      .addSelect('p.hora_fin', 'hora_fin')
      .addSelect('p.hora_inicio', 'hora_inicio')
      .addSelect('p.hora_max_recoger', 'hora_max_recoger')
      .addSelect('p.id_equipo', 'id_equipo')
      .addSelect('p.id_operador_entrega', 'id_operador_entrega')
      .addSelect('p.id_operador_regreso', 'id_operador_regreso')
      .addSelect('p.id_usuario', 'id_usuario')
      .addSelect('e.id_carrito', 'id_carrito')
      .addSelect('e.id_status', 'id_status')
      .addSelect('e.numero_inventario', 'numero_inventario')
      .addSelect('u.usuario', 'usuario')
      .addSelect('c.id_modulo', 'id_modulo')
      .addSelect('c.id_tipo_carrito', 'id_tipo_carrito')
      .addSelect('m.id_institucion', 'id_institucion')
      .from(Prestamo, 'p')
      .innerJoin(Equipo, 'e', 'e.id_equipo = p.id_equipo')
      .innerJoin(Operador, 'oe', 'oe.id_operador = p.id_operador_entrega')
      .innerJoin(Operador, 'or', 'or.id_operador = p.id_operador_regreso')
      .innerJoin(Usuario, 'u', 'u.id_usuario = p.id_usuario')
      .innerJoin(Carrito, 'c', 'c.id_carrito = e.id_carrito')
      .innerJoin(Status, 's', 's.id_status = e.id_status')
      .innerJoin(Modulo, 'm', 'm.id_modulo = c.id_modulo')
      .innerJoin(TipoCarrito, 'tc', 'tc.id_tipo_carrito = c.id_tipo_carrito')
      .innerJoin(Institucion, 'i', 'i.id_institucion = m.id_institucion'),
})
export class InformacionPrestamoView {
  @ViewColumn()
  id_prestamo: number;

  @ViewColumn()
  activo_prestamo: boolean;

  @ViewColumn()
  cancelado_operador: boolean;

  @ViewColumn()
  cancelado_usuario: boolean;

  @ViewColumn()
  fecha_entrega: Date;

  @ViewColumn()
  fecha_inicio: Date;

  @ViewColumn()
  hora_fin: Date;

  @ViewColumn()
  hora_inicio: Date;

  @ViewColumn()
  hora_max_recoger: Date;

  @ViewColumn()
  id_carrito: number;

  @ViewColumn()
  id_equipo: number;

  @ViewColumn()
  id_institucion: number;

  @ViewColumn()
  id_modulo: number;

  @ViewColumn()
  id_operador_entrega: number;

  @ViewColumn()
  id_operador_regreso: number;

  @ViewColumn()
  id_status: number;

  @ViewColumn()
  id_tipo_carrito: number;

  @ViewColumn()
  id_usuario: number;

  @ViewColumn()
  numero_inventario: string;

  @ViewColumn()
  usuario: string;
}
